@@ -3,24 +3,19 @@
 #' @description Create a representation of a row that can be inserted in a FlexTable.
 #' 
 #' @param values Optional. a character vector to use as text content, the row will contain as many cells as there are in \code{values}.
-#' @param textProp Optional. textProperties to apply to each cell. Used only if values are not missing.
-#' @param parProp Optional. parProperties to apply to each cell. Used only if values are not missing.
-#' @param cellProp Optional. cellProperties to apply to each cell. Used only if values are not missing.
+#' @param text.properties Optional. textProperties to apply to each cell. Used only if values are not missing.
+#' @param par.properties Optional. parProperties to apply to each cell. Used only if values are not missing.
+#' @param cell.properties Optional. cellProperties to apply to each cell. Used only if values are not missing.
 #' @param colspan integer Optional. vector specifying for each element the number of columns to span for each corresponding value (in \code{values}). 
 #' @export
-#' @seealso \code{\link{addFlexTable}}
+#' @seealso \code{\link{FlexTable}}, \code{\link{addFlexTable}}, \code{\link{alterFlexRow}} 
+#' , \code{\link{addHeaderRow}}, \code{\link{addFooterRow}}
 #' @examples
 #' #START_TAG_TEST
-#' ## example 1
-#' headerRow = FlexRow()
-#' headerRow[1] = FlexCell( "Column 1", cellProp = cellProperties(background.color="#527578")  )
-#' headerRow[2] = FlexCell( "Column 2", cellProp = cellProperties(background.color="#527578")  )
-#' 
-#' ## example 2
-#' headerRow = FlexRow( c("Column 1", "Column 2")
-#' 	, cellProp = cellProperties(background.color="#527578") )
-#' #STOP_TAG_TEST
-FlexRow = function( values, colspan, textProp = textProperties(), parProp = parProperties(), cellProp = cellProperties()){
+#' @example examples/FlexRow1.R
+#' @example examples/FlexRow2.R
+#' @example examples/STOP_TAG_TEST.R
+FlexRow = function( values, colspan, text.properties = textProperties(), par.properties = parProperties(), cell.properties = cellProperties()){
 	.Object = list()
 	.Object$jobj = .jnew(class.FlexRow)
 	class( .Object ) = c("FlexRow", "FlexElement")
@@ -29,11 +24,12 @@ FlexRow = function( values, colspan, textProp = textProperties(), parProp = parP
 		if( !is.character( values ) ) stop("argument 'values' must be a character vector.")
 		if( missing( colspan ) ) colspan = rep(1, length( values ) )
 		if( length( colspan ) != length( values ) ) stop("Length of colspan is different from length of values.")
+		if( any( is.na( values ) ) ) values[is.na(values)] = "NA"
 		for(i in 1:length( values ) )
-			.Object[i] = FlexCell( value = pot( values[i], format = textProp )
+			.Object[i] = FlexCell( value = pot( values[i], format = text.properties )
 				, colspan = colspan[i]
-				, parProp = parProp
-				, cellProp = cellProp 
+				, par.properties = par.properties
+				, cell.properties = cell.properties 
 				)
 	}
 	.Object
@@ -41,22 +37,38 @@ FlexRow = function( values, colspan, textProp = textProperties(), parProp = parP
 
 #' @method length FlexRow
 #' @S3method length FlexRow
-length.FlexRow <- function(x) {
+length.FlexRow = function(x) {
 	return(.jcall( x$jobj, "I", "size" ))
 }
 
-weight.FlexRow <- function(x) {
+weight.FlexRow = function(x) {
 	return(.jcall( x$jobj, "I", "weight" ))
 }
 
+#' @title modify FlexRow content
+#'
+#' @description add or replace FlexCell into a FlexRow object
+#' 
+#' @param x the \code{FlexRow} object
+#' @param i a single integer value. 
+#' @param value an object of class \code{\link{FlexCell}}
+#' @export
+#' @seealso \code{\link{FlexTable}}, \code{\link{addFlexTable}}, \code{\link{FlexRow}} 
+#' , \code{\link{addHeaderRow}}, \code{\link{addFooterRow}}
+#' @examples
+#' #START_TAG_TEST
+#' @example examples/FlexRow2.R
+#' @example examples/STOP_TAG_TEST.R
+#' @rdname FlexRow-alter
+#' @aliases alterFlexRow
 #' @method [<- FlexRow
 #' @S3method [<- FlexRow
-"[<-.FlexRow" = function (x, i, j, value){
+"[<-.FlexRow" = function (x, i, value){
 	if( missing(i) ) stop("subset argument is missing.")
 	if( !is.numeric(i) ) stop("subset must be defined with a scalar integer argument.")
 	if( length(i) != 1 ) stop("subset length is not of length 1.")
 	
-	i <- as.integer(i)
+	i = as.integer(i)
 	
 	doReplace = FALSE
 	if( i <= length(x) ) {
