@@ -3,15 +3,19 @@
 #' @description
 #' Insert paragraph(s) of text into a \code{pptx} object
 #' 
-#' @param doc Object of class \code{"pptx"} where paragraph has to be added
-#' @param value character vector containing texts to add OR an object of class \code{\link{set_of_paragraphs}}.
-#' @param offx optional, x position of the shape (top left position of the bounding box) in inch. See details.
-#' @param offy optional, y position of the shape (top left position of the bounding box) in inch. See details.
+#' @param doc \code{\link{pptx}} object where paragraph is added
+#' @param value text to add to the document as paragraphs: 
+#' an object of class \code{\link{pot}} or \code{\link{set_of_paragraphs}} 
+#' or a character vector.
+#' @param offx optional, x position of the shape (top left position of the bounding box) 
+#' in inch. See details.
+#' @param offy optional, y position of the shape (top left position of the bounding box) 
+#' in inch. See details.
 #' @param width optional, width of the shape in inch. See details.
 #' @param height optional, height of the shape in inch. See details.
 #' @param par.properties a parProperties object
 #' @param ... further arguments, not used. 
-#' @return an object of class \code{"pptx"}.
+#' @return an object of class \code{\link{pptx}}.
 #' @details
 #' If arguments offx, offy, width, height are missing, position and dimensions
 #' will be defined by the width and height of the next available shape of the slide. This 
@@ -51,30 +55,47 @@ addParagraph.pptx = function(doc, value, offx, offy, width, height, par.properti
 		x = lapply( value, function(x) pot(value = x) )
 		value = do.call( "set_of_paragraphs", x )
 	}
+	if( inherits( value, "pot" ) ){
+		value = set_of_paragraphs( value )
+	}
+	
+	if( !inherits(value, "set_of_paragraphs") )
+		stop("value must be an object of class pot, set_of_paragraphs or a character vector.")
 	
 	if( !inherits( par.properties, "parProperties" ) ){
 		stop("argument 'par.properties' must be an object of class 'parProperties'")
 	}
 	
 	
-	if( inherits(value, "set_of_paragraphs") ){
-		slide = doc$current_slide 
-		paragrahSection = ParagraphSection (value, par.properties )
-		paragrah = .jnew(class.pptx4r.Paragraphs)
-		.jcall( paragrah, "V", "setTextBody", paragrahSection$jobj)
-
-		if( !missing( offx )){
-			out = .jcall( slide, "I", "add", paragrah
-					, as.double( offx ), as.double( offy ), as.double( width ), as.double( height ) )
-		} else {
-			out = .jcall( slide, "I", "add" , paragrah)
-		}	
-
-		if( isSlideError( out ) ){
-			stop( getSlideErrorString( out , "pot") )
+	slide = doc$current_slide 
+	
+	
+	parset = .jnew( class.ParagraphSet, .jParProperties(par.properties) )
+	
+	for( pot_index in 1:length( value ) ){
+		paragrah = .jnew(class.Paragraph )
+		pot_value = value[[pot_index]]
+		for( i in 1:length(pot_value)){
+			if( is.null( pot_value[[i]]$format ) ) 
+				.jcall( paragrah, "V", "addText", pot_value[[i]]$value )
+			else .jcall( paragrah, "V", "addText", pot_value[[i]]$value, 
+						.jTextProperties( pot_value[[i]]$format) )
 		}
-	} else stop("value must be an object of class 'set_of_paragraphs' or a character vector!")
-
+		.jcall( parset, "V", "addParagraph", paragrah )
+	}
+	
+	
+	if( !missing( offx )){
+		out = .jcall( slide, "I", "add", parset
+				, as.double( offx ), as.double( offy ), as.double( width ), as.double( height ) )
+	} else {
+		out = .jcall( slide, "I", "add" , parset)
+	}	
+	
+	if( isSlideError( out ) ){
+		stop( getSlideErrorString( out , "pot") )
+	}
+	
 	doc
 }
 
