@@ -31,6 +31,7 @@ raphael = function( file, width=504, height=504, offx = 50, offy = 50, ps=12, fo
 	#assign("canvas_id", as.integer( canvas_id ), envir = env)
 	assign("plot_ids", list(), envir = env)
 	assign("element_ids", list(), envir = env)
+	assign("post_commands", list(), envir = env)
 	.Call("R_RAPHAEL_Device", file, as.double(width), as.double(height)
 			, as.double(offx), as.double(offy), as.double(ps), fontname 
 			, as.integer( canvas_id ), env
@@ -55,6 +56,34 @@ registerRaphaelGraph = function( plot_attributes, env ){
 	invisible()
 }
 
+#' @title add post plot commands
+#'
+#' @description internal use only
+#' @param labels labels
+#' @param ids ids
+#' @param env environment
+#' @export 
+addPostCommand = function( labels, ids, env ){
+	post_commands = get("post_commands" , envir = env )
+	post_commands[[ length(post_commands) + 1 ]] = list( ids = ids, popup.labels = labels, len = length(ids) )
+	assign("post_commands", post_commands, envir = env)
+	invisible()
+}
+
+#' @title trigger post plot commands
+#'
+#' @description internal use only
+#' @param env environment
+#' @export 
+triggerPostCommand = function( env ){
+	post_commands = get("post_commands" , envir = env )	
+	for( cmds in post_commands ){
+		.C("add_popup", (dev.cur()-1L), as.integer(cmds$ids), as.character( cmds$popup.labels ), cmds$len )
+	}
+	assign("post_commands", list(), envir = env)
+	invisible()
+}
+
 check.fontfamily = function( fontfamily ){
 	
 	if( !is.character( fontfamily ) ){
