@@ -9,7 +9,6 @@
 #' @seealso \code{\link{addTable}}
 #' , \code{\link{get.light.tableProperties}}
 #' , \code{\link{get.greenheader.tableProperties}}
-#' , \code{\link{get.darker.tableProperties}}
 get.default.tableProperties = function(){
 	
 	
@@ -55,7 +54,6 @@ get.default.tableProperties = function(){
 #' @seealso \code{\link{addTable}}
 #' , \code{\link{get.default.tableProperties}}
 #' , \code{\link{get.greenheader.tableProperties}}
-#' , \code{\link{get.darker.tableProperties}}
 get.light.tableProperties = function(){
 	
 	tableProperties( header.text = textProperties( color = "#102E37", font.weight="bold", font.size=12 )
@@ -79,7 +77,6 @@ get.light.tableProperties = function(){
 #' @seealso \code{\link{addTable}}
 #' , \code{\link{get.default.tableProperties}}
 #' , \code{\link{get.light.tableProperties}}
-#' , \code{\link{get.darker.tableProperties}}
 get.greenheader.tableProperties = function(){
 	
 	tableProperties( header.text = textProperties( color = "#333333", font.weight="bold", font.size=12 )
@@ -96,29 +93,4 @@ get.greenheader.tableProperties = function(){
 	)
 }
 
-#' @title get a darker tableProperties 
-#'
-#' @description
-#' darker tableProperties object
-#' 
-#' @export
-#' @examples
-#' get.darker.tableProperties()
-#' @seealso \code{\link{addTable}}
-#' , \code{\link{get.default.tableProperties}}
-#' , \code{\link{get.light.tableProperties}}
-#' , \code{\link{get.greenheader.tableProperties}}
-get.darker.tableProperties = function(){
-	tableProperties( 
-		header.text = textProperties( color = "#E8EDE0", font.weight="bold", font.size=12 )
-		, header.par = parProperties( text.align = "right", padding.bottom=2, padding.top=2, padding.right=10, padding.left=10 )
-		, header.cell = cellProperties(background.color= "#102E37", border.color="#F78D3F")
-		, groupedheader.text = textProperties( color = "#E8EDE0", font.weight="bold", font.size=12 )
-		, groupedheader.par = parProperties( text.align = "right", padding.bottom=2, padding.top=2, padding.right=10, padding.left=10 )
-		, groupedheader.cell = cellProperties(background.color= "#102E37", border.color="#F78D3F")
-		, data.par = parProperties( text.align = "right" )
-		, data.cell = cellProperties( background.color = "#E8EDE0", border.color="#F78D3F")
-		, data.text = textProperties( color = "#102E37", font.size=12)
-		, percent.addsymbol= " (%)" , fraction.double.digit=2, fraction.percent.digit=1
-	)
-}
+
